# Take-a-Break
[![Build Status](https://travis-ci.org/paulbrodner/take-a-break.svg?branch=master)](https://travis-ci.org/paulbrodner/take-a-break)
> a small python application that will remind me to take breaks after a period of time (configured).

> when triggered - this app will display a random image from [unsplash](https://unsplash.com/) followed by a random [joke](http://api.icndb.com/jokes/random)

# why
> i've built this app just to learn how to build a python package from scratch, how to version control it, test it and release it using [travis-ci.org](https://travis-ci.org/)

# installation
```shell script
pip install take-a-break
```

# usage
```shell script
python -m take_a_break
```
> the application will remain opened in console and will be displayed a nofification after x minutes

# thank you
>* [handdrawngoods](http://handdrawngoods.com) for free [icon.ico](https://icon-icons.com/icon/coffe-cup/87565) 

>* [icndb.com](http://www.icndb.com/) for funny jokes

>* [unsplash](https://unsplash.com/) for free images